from smartcard.util import toHexString
expectedReaders = ['Gemplus GemPC Key 00 00', 'SCM SCR 3310 (21120432100019) 01 00']
expectedATRs = [[59, 22, 24, 32, 2, 1, 0, 128, 13], [59, 119, 148, 0, 0, 130, 48, 0, 19, 108, 159, 34]]
expectedATRinReader = {} 
for i in xrange(len(expectedReaders)): 
	expectedATRinReader[expectedReaders[i]]=expectedATRs[i] 
expectedReaderForATR = {} 
for i in xrange(len(expectedReaders)): 
	expectedReaderForATR[toHexString(expectedATRs[i])]=expectedReaders[i] 
expectedReaderGroups = [ 'SCard$DefaultReaders' ] 
